Sign in to your Mocavo account

×

### Forgot Your Password?

× Login or email doesn't exist.
× Message Sent. Please check your email for password reset instructions.

Don't worry, it happens to us all the time. Just enter the email address that you signed up with below and we'll send you instructions to reset your password right away.

E-Mail

Please fill out all of the fields before submitting.

# Sign In to Your Account

E-Mail Address
Password Forgot?

Not a member? Sign up now

## Upload Your Story with Mocavo

- ##

  ### Upload
  a Tree

- ##

  ### Upload
  a Document

- ##

  ### Upload
  a Database

## Upload Your Family Tree

- ##

  ### Upload
  from Desktop

## Upload a Document

- ##

  ### Upload
  from Desktop

### Select Family Tree File (Step 1 of 2)

Choose File from Your Computer

### Upload a Family Tree (Step 2 of 2)

Give this Tree a Name

### Upload a Document (Step 1 of 2)

Choose File

### Suggest a Site

We are always on the lookout for new resources to add to our database. If you have a website that you believe would benefit our community, please let us know.

Website URL (please provide a URL)
Your Email (please provide a valid email)
Brief Description (please provide a brief description)

### Upload a Database

We are always on the lookout for new records to add to our database. If you have a resource that you would like to contribute to our community, please let us know and we will be in touch as soon as possible.

Your Name Your E-Mail Please Describe Your Database Please Categorize Your Database